@@ -200,9 +200,12 @@ CBOREncoder_init(CBOREncoderObject *self, PyObject *args, PyObject *kwargs)
 static PyObject *
 _CBOREncoder_get_fp(CBOREncoderObject *self, void *closure)
 {
-    PyObject *ret = PyMethod_GET_SELF(self->write);
-    Py_INCREF(ret);
-    return ret;
+    PyObject *fp = PyObject_GetAttrString(self->write, "__self__");
+    if (fp) {
+        return fp;
+    } else {
+        Py_RETURN_NONE;
+    }
 }
 
 
@@ -1628,7 +1631,7 @@ CBOREncoder_encode_simple_value(CBOREncoderObject *self, PyObject *args)
 
     if (!PyArg_ParseTuple(args, "B", &value))
         return NULL;
-    if (value < 20) {
+    if (value < 24) {
         value |= 0xE0;
         if (fp_write(self, (char *)&value, 1) == -1)
             return NULL;
