@@ -10,8 +10,11 @@ from ipaddress import ip_address, ip_network
 from uuid import UUID
 
 import pytest
-from cbor2 import shareable_encoder
-from cbor2.types import FrozenDict
+from hypothesis import given
+
+from cbor2 import FrozenDict, shareable_encoder
+
+from .hypothesis_strategies import compound_types_strategy
 
 
 def test_fp_attr(impl):
@@ -195,7 +198,7 @@ def test_special(impl, special_values):
     assert impl.dumps(value) == expected
 
 
-@pytest.fixture(params=[(0, "e0"), (2, "e2"), (19, "f3"), (32, "f820")])
+@pytest.fixture(params=[(0, "e0"), (2, "e2"), (23, "f7"), (32, "f820")])
 def simple_values(request, impl):
     value, expected = request.param
     return impl.CBORSimpleValue(value), expected
@@ -265,10 +268,7 @@ def test_simple_val_as_key(impl):
 )
 def test_datetime(impl, value, as_timestamp, expected):
     expected = unhexlify(expected)
-    assert (
-        impl.dumps(value, datetime_as_timestamp=as_timestamp, timezone=timezone.utc)
-        == expected
-    )
+    assert impl.dumps(value, datetime_as_timestamp=as_timestamp, timezone=timezone.utc) == expected
 
 
 @pytest.mark.parametrize("tz", [None, timezone.utc], ids=["no timezone", "utc"])
@@ -282,10 +282,7 @@ def test_date_fails(impl, tz):
 
 def test_date_as_datetime(impl):
     expected = unhexlify("c074323031332d30332d32315430303a30303a30305a")
-    assert (
-        impl.dumps(date(2013, 3, 21), timezone=timezone.utc, date_as_datetime=True)
-        == expected
-    )
+    assert impl.dumps(date(2013, 3, 21), timezone=timezone.utc, date_as_datetime=True) == expected
 
 
 def test_naive_datetime(impl):
@@ -607,9 +604,7 @@ def test_encode_stringrefs_array(impl):
         impl.CBORTag(25, 0),
         impl.CBORTag(25, 1),
     ]
-    assert impl.dumps(value, string_referencing=True) == b"\xd9\x01\x00" + impl.dumps(
-        equivalent
-    )
+    assert impl.dumps(value, string_referencing=True) == b"\xd9\x01\x00" + impl.dumps(equivalent)
 
 
 def test_encode_stringrefs_dict(impl):
@@ -629,9 +624,7 @@ def test_encode_stringrefs_dict(impl):
     assert impl.dumps(value, string_referencing=True, canonical=True) == expected
 
 
-@pytest.mark.parametrize(
-    "tag", [-1, 2**64, "f"], ids=["too small", "too large", "wrong type"]
-)
+@pytest.mark.parametrize("tag", [-1, 2**64, "f"], ids=["too small", "too large", "wrong type"])
 def test_invalid_tag(impl, tag):
     with pytest.raises(TypeError):
         impl.dumps(impl.CBORTag(tag, "value"))
@@ -640,3 +633,12 @@ def test_invalid_tag(impl, tag):
 def test_largest_tag(impl):
     expected = unhexlify("dbffffffffffffffff6176")
     assert impl.dumps(impl.CBORTag(2**64 - 1, "v")) == expected
+
+
+@given(compound_types_strategy)
+def test_invariant_encode_decode(impl, val):
+    """
+    Tests that an encode and decode is invariant (the value is the same after
+    undergoing an encode and decode)
+    """
+    assert impl.loads(impl.dumps(val)) == val
